library(testthat)
library(waterquality)
library(terra)

test_check("waterquality")
